.. Turbinia documentation master file, created by
   sphinx-quickstart on Fri Jul 17 14:51:54 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Turbinia's documentation!
====================================

Turbinia is an open-source framework for deploying, managing, and running distributed forensic workloads.

The source code is available from https://github.com/google/turbinia

Contents:

.. toctree::
   :maxdepth: 3
   
   user/index

.. toctree::
   :maxdepth: 3
   
   developer/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
